@@ -5,57 +5,32 @@
 # License: https://www.pysnmp.com/pysnmp/license.html
 #
 import sys
+
+from pyasn1.type import univ
+from pysnmp import debug, error, nextid
 from pysnmp.entity.engine import SnmpEngine
 from pysnmp.entity.rfc3413 import config
-from pysnmp.proto import rfc1905, errind
+from pysnmp.proto import errind
 from pysnmp.proto.api import v2c
-from pysnmp.proto.proxy import rfc2576
-from pysnmp import error, nextid, debug
 from pysnmp.proto.error import StatusInformation
-from pyasn1.type import univ
+from pysnmp.proto.proxy import rfc2576
 
-getNextHandle = nextid.Integer(0x7FFFFFFF)
-
-__null = univ.Null("")
-
-
-def getNextVarBinds(varBinds, origVarBinds=None):
-    errorIndication = None
-    idx = nonNulls = len(varBinds)
-    rspVarBinds = []
-    while idx:
-        idx -= 1
-        if varBinds[idx][1].tagSet in (
-            rfc1905.NoSuchObject.tagSet,
-            rfc1905.NoSuchInstance.tagSet,
-            rfc1905.EndOfMibView.tagSet,
-        ):
-            nonNulls -= 1
-        elif origVarBinds is not None:
-            if (
-                v2c.ObjectIdentifier(origVarBinds[idx][0]).asTuple()
-                >= varBinds[idx][0].asTuple()
-            ):
-                errorIndication = errind.oidNotIncreasing
-
-        rspVarBinds.insert(0, (varBinds[idx][0], __null))
-
-    if not nonNulls:
-        rspVarBinds = []
-
-    return errorIndication, rspVarBinds
+getNextHandle = nextid.Integer(0x7FFFFFFF)  # noqa: N816
 
 
 class CommandGenerator:
+    """SNMP command generator."""
+
     _null = univ.Null("")
 
     def __init__(self, **options):
+        """Create a command generator object."""
         self.__options = options
         self.__pendingReqs = {}
 
-    def processResponsePdu(
+    def process_response_pdu(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         messageProcessingModel,
         securityModel,
         securityName,
@@ -68,6 +43,7 @@ class CommandGenerator:
         sendPduHandle,
         cbCtx,
     ):
+        """Process SNMP response."""
         origSendRequestHandle, cbFun, cbCtx = cbCtx
 
         # 3.1.1
@@ -91,11 +67,11 @@ class CommandGenerator:
             origDiscoveryRetries,
         ) = self.__pendingReqs.pop(sendPduHandle)
 
-        snmpEngine.transportDispatcher.jobFinished(id(self))
+        snmpEngine.transport_dispatcher.job_finished(id(self))
 
         # 3.1.3
         if statusInformation:
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 f"processResponsePdu: sendPduHandle {sendPduHandle}, statusInformation {statusInformation}"
             )
 
@@ -112,7 +88,7 @@ class CommandGenerator:
                 origRetries > origRetryCount
                 or origDiscoveryRetries > self.__options.get("discoveryRetries", 4)
             ):
-                debug.logger & debug.flagApp and debug.logger(
+                debug.logger & debug.FLAG_APP and debug.logger(
                     "processResponsePdu: sendPduHandle %s, retry count %d exceeded"
                     % (sendPduHandle, origRetries)
                 )
@@ -121,14 +97,14 @@ class CommandGenerator:
 
             # User-side API assumes SMIv2
             if origMessageProcessingModel == 0:
-                reqPDU = rfc2576.v2ToV1(origPdu)
+                reqPDU = rfc2576.v2_to_v1(origPdu)
                 pduVersion = 0
             else:
                 reqPDU = origPdu
                 pduVersion = 1
 
             try:
-                sendPduHandle = snmpEngine.msgAndPduDsp.sendPdu(
+                sendPduHandle = snmpEngine.message_dispatcher.send_pdu(
                     snmpEngine,
                     origTransportDomain,
                     origTransportAddress,
@@ -142,11 +118,11 @@ class CommandGenerator:
                     reqPDU,
                     True,
                     origTimeout,
-                    self.processResponsePdu,
+                    self.process_response_pdu,
                     (origSendRequestHandle, cbFun, cbCtx),
                 )
 
-                snmpEngine.transportDispatcher.jobStarted(id(self))
+                snmpEngine.transport_dispatcher.job_started(id(self))
 
                 self.__pendingReqs[sendPduHandle] = (
                     origTransportDomain,
@@ -168,7 +144,7 @@ class CommandGenerator:
 
             except StatusInformation:
                 statusInformation = sys.exc_info()[1]
-                debug.logger & debug.flagApp and debug.logger(
+                debug.logger & debug.FLAG_APP and debug.logger(
                     "processResponsePdu: origSendRequestHandle {}, _sendPdu() failed with {!r}".format(
                         sendPduHandle, statusInformation
                     )
@@ -192,7 +168,7 @@ class CommandGenerator:
             and origContextName != contextName
             or origPduVersion != pduVersion
         ):
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponsePdu: sendPduHandle %s, request/response data mismatch"
                 % sendPduHandle
             )
@@ -202,11 +178,11 @@ class CommandGenerator:
 
         # User-side API assumes SMIv2
         if messageProcessingModel == 0:
-            PDU = rfc2576.v1ToV2(PDU, origPdu)
+            PDU = rfc2576.v1_to_v2(PDU, origPdu)
 
         # 3.1.2
-        if v2c.apiPDU.getRequestID(PDU) != v2c.apiPDU.getRequestID(origPdu):
-            debug.logger & debug.flagApp and debug.logger(
+        if v2c.apiPDU.get_request_id(PDU) != v2c.apiPDU.get_request_id(origPdu):
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponsePdu: sendPduHandle %s, request-id/response-id mismatch"
                 % sendPduHandle
             )
@@ -215,7 +191,7 @@ class CommandGenerator:
 
         cbFun(snmpEngine, origSendRequestHandle, None, PDU, cbCtx)
 
-    def sendPdu(
+    def send_pdu(
         self,
         snmpEngine: SnmpEngine,
         targetName,
@@ -225,6 +201,7 @@ class CommandGenerator:
         cbFun,
         cbCtx,
     ):
+        """Send SNMP PDU."""
         (
             transportDomain,
             transportAddress,
@@ -234,16 +211,18 @@ class CommandGenerator:
             securityModel,
             securityName,
             securityLevel,
-        ) = config.getTargetInfo(snmpEngine, targetName)
+        ) = config.get_target_info(snmpEngine, targetName)
 
-        if snmpEngine.transportDispatcher is None:
+        if snmpEngine.transport_dispatcher is None:
             raise error.PySnmpError("No transport dispatcher available")
         # Convert timeout in seconds into timeout in timer ticks
         timeoutInTicks = (
-            float(timeout) / 100 / snmpEngine.transportDispatcher.getTimerResolution()
+            float(timeout)
+            / 100
+            / snmpEngine.transport_dispatcher.get_timer_resolution()
         )
 
-        SnmpEngineID, SnmpAdminString = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols(  # type: ignore
+        SnmpEngineID, SnmpAdminString = snmpEngine.get_mib_builder().import_symbols(  # type: ignore
             "SNMP-FRAMEWORK-MIB", "SnmpEngineID", "SnmpAdminString"
         )
 
@@ -256,7 +235,7 @@ class CommandGenerator:
 
         # User-side API assumes SMIv2
         if messageProcessingModel == 0:
-            PDU = rfc2576.v2ToV1(PDU)
+            PDU = rfc2576.v2_to_v1(PDU)
             pduVersion = 0
         else:
             pduVersion = 1
@@ -264,7 +243,7 @@ class CommandGenerator:
         sendRequestHandle = getNextHandle()
 
         # 3.1
-        sendPduHandle = snmpEngine.msgAndPduDsp.sendPdu(
+        sendPduHandle = snmpEngine.message_dispatcher.send_pdu(
             snmpEngine,
             transportDomain,
             transportAddress,
@@ -278,11 +257,11 @@ class CommandGenerator:
             PDU,
             True,
             timeoutInTicks,
-            self.processResponsePdu,
+            self.process_response_pdu,
             (sendRequestHandle, cbFun, cbCtx),
         )
 
-        snmpEngine.transportDispatcher.jobStarted(id(self))
+        snmpEngine.transport_dispatcher.job_started(id(self))
 
         self.__pendingReqs[sendPduHandle] = (
             transportDomain,
@@ -301,7 +280,7 @@ class CommandGenerator:
             0,
         )
 
-        debug.logger & debug.flagApp and debug.logger(
+        debug.logger & debug.FLAG_APP and debug.logger(
             "sendPdu: sendPduHandle %s, timeout %d*10 ms/%d ticks, retry 0 of %d"
             % (sendPduHandle, timeout, timeoutInTicks, retryCount)
         )
@@ -309,29 +288,28 @@ class CommandGenerator:
         return sendRequestHandle
 
 
-# backward compatibility stub
-CommandGeneratorBase = CommandGenerator
-
-
 class GetCommandGenerator(CommandGenerator):
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
+    """SNMP GET command generator."""
+
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
     ):
+        """Process SNMP GET response."""
         cbFun, cbCtx = cbCtx
 
         cbFun(
             snmpEngine,
             sendRequestHandle,
             errorIndication,
-            PDU and v2c.apiPDU.getErrorStatus(PDU) or 0,
-            PDU and v2c.apiPDU.getErrorIndex(PDU, muteErrors=True) or 0,
-            PDU and v2c.apiPDU.getVarBinds(PDU) or (),
+            PDU and v2c.apiPDU.get_error_status(PDU) or 0,
+            PDU and v2c.apiPDU.get_error_index(PDU, muteErrors=True) or 0,
+            PDU and v2c.apiPDU.get_varbinds(PDU) or (),
             cbCtx,
         )
 
-    def sendVarBinds(
+    def send_varbinds(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         targetName,
         contextEngineId,
         contextName,
@@ -339,41 +317,45 @@ class GetCommandGenerator(CommandGenerator):
         cbFun,
         cbCtx=None,
     ):
+        """Send SNMP GET request."""
         reqPDU = v2c.GetRequestPDU()
-        v2c.apiPDU.setDefaults(reqPDU)
+        v2c.apiPDU.set_defaults(reqPDU)
 
-        v2c.apiPDU.setVarBinds(reqPDU, varBinds)
+        v2c.apiPDU.set_varbinds(reqPDU, varBinds)
 
-        return self.sendPdu(
+        return self.send_pdu(
             snmpEngine,
             targetName,
             contextEngineId,
             contextName,
             reqPDU,
-            self.processResponseVarBinds,
+            self.process_response_varbinds,
             (cbFun, cbCtx),
         )
 
 
 class SetCommandGenerator(CommandGenerator):
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
+    """SNMP SET command generator."""
+
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
     ):
+        """Process SNMP SET response."""
         cbFun, cbCtx = cbCtx
 
         cbFun(
             snmpEngine,
             sendRequestHandle,
             errorIndication,
-            PDU and v2c.apiPDU.getErrorStatus(PDU) or 0,
-            PDU and v2c.apiPDU.getErrorIndex(PDU, muteErrors=True) or 0,
-            PDU and v2c.apiPDU.getVarBinds(PDU) or (),
+            PDU and v2c.apiPDU.get_error_status(PDU) or 0,
+            PDU and v2c.apiPDU.get_error_index(PDU, muteErrors=True) or 0,
+            PDU and v2c.apiPDU.get_varbinds(PDU) or (),
             cbCtx,
         )
 
-    def sendVarBinds(
+    def send_varbinds(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         targetName,
         contextEngineId,
         contextName,
@@ -381,41 +363,45 @@ class SetCommandGenerator(CommandGenerator):
         cbFun,
         cbCtx=None,
     ):
+        """Send SNMP SET request."""
         reqPDU = v2c.SetRequestPDU()
-        v2c.apiPDU.setDefaults(reqPDU)
+        v2c.apiPDU.set_defaults(reqPDU)
 
-        v2c.apiPDU.setVarBinds(reqPDU, varBinds)
+        v2c.apiPDU.set_varbinds(reqPDU, varBinds)
 
-        return self.sendPdu(
+        return self.send_pdu(
             snmpEngine,
             targetName,
             contextEngineId,
             contextName,
             reqPDU,
-            self.processResponseVarBinds,
+            self.process_response_varbinds,
             (cbFun, cbCtx),
         )
 
 
 class NextCommandGeneratorSingleRun(CommandGenerator):
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
+    """Single-run SNMP GETNEXT command generator."""
+
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
     ):
+        """Process SNMP GETNEXT response."""
         targetName, contextEngineId, contextName, reqPDU, cbFun, cbCtx = cbCtx
 
         cbFun(
             snmpEngine,
             sendRequestHandle,
             errorIndication,
-            PDU and v2c.apiPDU.getErrorStatus(PDU) or 0,
-            PDU and v2c.apiPDU.getErrorIndex(PDU, muteErrors=True) or 0,
-            PDU and v2c.apiPDU.getVarBinds(PDU) or (),
+            PDU and v2c.apiPDU.get_error_status(PDU) or 0,
+            PDU and v2c.apiPDU.get_error_index(PDU, muteErrors=True) or 0,
+            PDU and v2c.apiPDU.get_varbinds(PDU) or (),
             cbCtx,
         )
 
-    def sendVarBinds(
+    def send_varbinds(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         targetName,
         contextEngineId,
         contextName,
@@ -423,53 +409,53 @@ class NextCommandGeneratorSingleRun(CommandGenerator):
         cbFun,
         cbCtx=None,
     ):
+        """Send SNMP GETNEXT request."""
         reqPDU = v2c.GetNextRequestPDU()
-        v2c.apiPDU.setDefaults(reqPDU)
+        v2c.apiPDU.set_defaults(reqPDU)
 
-        v2c.apiPDU.setVarBinds(reqPDU, varBinds)
+        v2c.apiPDU.set_varbinds(reqPDU, varBinds)
 
-        return self.sendPdu(
+        return self.send_pdu(
             snmpEngine,
             targetName,
             contextEngineId,
             contextName,
             reqPDU,
-            self.processResponseVarBinds,
+            self.process_response_varbinds,
             (targetName, contextEngineId, contextName, reqPDU, cbFun, cbCtx),
         )
 
 
 class NextCommandGenerator(NextCommandGeneratorSingleRun):
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
+    """SNMP GETNEXT command generator."""
+
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
     ):
+        """Process SNMP GETNEXT response."""
         targetName, contextEngineId, contextName, reqPDU, cbFun, cbCtx = cbCtx
 
         if errorIndication:
             cbFun(snmpEngine, sendRequestHandle, errorIndication, 0, 0, (), cbCtx)
             return
 
-        varBindTable = v2c.apiPDU.getVarBindTable(reqPDU, PDU)
+        varBinds = v2c.apiPDU.get_varbinds(PDU)
 
-        if v2c.apiPDU.getErrorStatus(PDU):
+        if v2c.apiPDU.get_error_status(PDU):
             errorIndication, varBinds = None, ()
-        elif not varBindTable:
+        elif not varBinds:
             errorIndication, varBinds = errind.emptyResponse, ()
-        else:
-            errorIndication, varBinds = getNextVarBinds(
-                varBindTable[-1], v2c.apiPDU.getVarBinds(reqPDU)
-            )
 
         if not cbFun(
             snmpEngine,
             sendRequestHandle,
             errorIndication,
-            v2c.apiPDU.getErrorStatus(PDU),
-            v2c.apiPDU.getErrorIndex(PDU, muteErrors=True),
-            varBindTable,
+            v2c.apiPDU.get_error_status(PDU),
+            v2c.apiPDU.get_error_index(PDU, muteErrors=True),
+            varBinds,
             cbCtx,
         ):
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponseVarBinds: sendRequestHandle %s, app says to stop walking"
                 % sendRequestHandle
             )
@@ -478,40 +464,14 @@ class NextCommandGenerator(NextCommandGeneratorSingleRun):
         if not varBinds:
             return  # no more objects available
 
-        v2c.apiPDU.setRequestID(reqPDU, v2c.getNextRequestID())
-        v2c.apiPDU.setVarBinds(reqPDU, varBinds)
-
-        try:
-            self.sendPdu(
-                snmpEngine,
-                targetName,
-                contextEngineId,
-                contextName,
-                reqPDU,
-                self.processResponseVarBinds,
-                (targetName, contextEngineId, contextName, reqPDU, cbFun, cbCtx),
-            )
-
-        except StatusInformation:
-            statusInformation = sys.exc_info()[1]
-            debug.logger & debug.flagApp and debug.logger(
-                f"sendVarBinds: sendPduHandle {sendRequestHandle}: sendPdu() failed with {statusInformation!r}"
-            )
-            cbFun(
-                snmpEngine,
-                sendRequestHandle,
-                statusInformation["errorIndication"],  # type: ignore
-                0,
-                0,
-                (),
-                cbCtx,
-            )
-
 
 class BulkCommandGeneratorSingleRun(CommandGenerator):
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
+    """Single-run SNMP GETBULK command generator."""
+
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
     ):
+        """Process SNMP GETBULK response."""
         (
             targetName,
             nonRepeaters,
@@ -527,15 +487,15 @@ class BulkCommandGeneratorSingleRun(CommandGenerator):
             snmpEngine,
             sendRequestHandle,
             errorIndication,
-            PDU and v2c.apiPDU.getErrorStatus(PDU) or 0,
-            PDU and v2c.apiPDU.getErrorIndex(PDU, muteErrors=True) or 0,
-            PDU and v2c.apiPDU.getVarBinds(PDU) or (),
+            PDU and v2c.apiPDU.get_error_status(PDU) or 0,
+            PDU and v2c.apiPDU.get_error_index(PDU, muteErrors=True) or 0,
+            PDU and v2c.apiPDU.get_varbinds(PDU) or (),
             cbCtx,
         )
 
-    def sendVarBinds(
+    def send_varbinds(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         targetName,
         contextEngineId,
         contextName,
@@ -545,21 +505,22 @@ class BulkCommandGeneratorSingleRun(CommandGenerator):
         cbFun,
         cbCtx=None,
     ):
+        """Send SNMP GETBULK request."""
         reqPDU = v2c.GetBulkRequestPDU()
-        v2c.apiBulkPDU.setDefaults(reqPDU)
+        v2c.apiBulkPDU.set_defaults(reqPDU)
 
-        v2c.apiBulkPDU.setNonRepeaters(reqPDU, nonRepeaters)
-        v2c.apiBulkPDU.setMaxRepetitions(reqPDU, maxRepetitions)
+        v2c.apiBulkPDU.set_non_repeaters(reqPDU, nonRepeaters)
+        v2c.apiBulkPDU.set_max_repetitions(reqPDU, maxRepetitions)
 
-        v2c.apiBulkPDU.setVarBinds(reqPDU, varBinds)
+        v2c.apiBulkPDU.set_varbinds(reqPDU, varBinds)
 
-        return self.sendPdu(
+        return self.send_pdu(
             snmpEngine,
             targetName,
             contextEngineId,
             contextName,
             reqPDU,
-            self.processResponseVarBinds,
+            self.process_response_varbinds,
             (
                 targetName,
                 nonRepeaters,
@@ -574,9 +535,12 @@ class BulkCommandGeneratorSingleRun(CommandGenerator):
 
 
 class BulkCommandGenerator(BulkCommandGeneratorSingleRun):
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
+    """Bulk SNMP GET command generator."""
+
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, PDU, cbCtx
     ):
+        """Process SNMP GETBULK response."""
         (
             targetName,
             nonRepeaters,
@@ -592,33 +556,23 @@ class BulkCommandGenerator(BulkCommandGeneratorSingleRun):
             cbFun(snmpEngine, sendRequestHandle, errorIndication, 0, 0, (), cbCtx)
             return
 
-        varBindTable = v2c.apiBulkPDU.getVarBindTable(reqPDU, PDU)
+        varBinds = v2c.apiBulkPDU.get_varbinds(PDU)
 
-        if v2c.apiBulkPDU.getErrorStatus(PDU):
+        if v2c.apiBulkPDU.get_error_status(PDU):
             errorIndication, varBinds = None, ()
-        elif not varBindTable:
+        elif not varBinds:
             errorIndication, varBinds = errind.emptyResponse, ()
-        else:
-            errorIndication, varBinds = getNextVarBinds(
-                varBindTable[-1], v2c.apiPDU.getVarBinds(reqPDU)
-            )
-            nonRepeaters = v2c.apiBulkPDU.getNonRepeaters(reqPDU)
-            if nonRepeaters:
-                varBinds = (
-                    v2c.apiBulkPDU.getVarBinds(reqPDU)[: int(nonRepeaters)]
-                    + varBinds[int(nonRepeaters) :]
-                )
 
         if not cbFun(
             snmpEngine,
             sendRequestHandle,
             errorIndication,
-            v2c.apiBulkPDU.getErrorStatus(PDU),
-            v2c.apiBulkPDU.getErrorIndex(PDU, muteErrors=True),
-            varBindTable,
+            v2c.apiBulkPDU.get_error_status(PDU),
+            v2c.apiBulkPDU.get_error_index(PDU, muteErrors=True),
+            varBinds,
             cbCtx,
         ):
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponseVarBinds: sendRequestHandle %s, app says to stop walking"
                 % sendRequestHandle
             )
@@ -626,118 +580,3 @@ class BulkCommandGenerator(BulkCommandGeneratorSingleRun):
 
         if not varBinds:
             return  # no more objects available
-
-        v2c.apiBulkPDU.setRequestID(reqPDU, v2c.getNextRequestID())
-        v2c.apiBulkPDU.setVarBinds(reqPDU, varBinds)
-
-        try:
-            self.sendPdu(
-                snmpEngine,
-                targetName,
-                contextEngineId,
-                contextName,
-                reqPDU,
-                self.processResponseVarBinds,
-                (
-                    targetName,
-                    nonRepeaters,
-                    maxRepetitions,
-                    contextEngineId,
-                    contextName,
-                    reqPDU,
-                    cbFun,
-                    cbCtx,
-                ),
-            )
-
-        except StatusInformation:
-            statusInformation = sys.exc_info()[1]
-            debug.logger & debug.flagApp and debug.logger(
-                "processResponseVarBinds: sendPduHandle {}: _sendPdu() failed with {!r}".format(
-                    sendRequestHandle, statusInformation
-                )
-            )
-            cbFun(
-                snmpEngine,
-                sendRequestHandle,
-                statusInformation["errorIndication"],
-                0,
-                0,
-                (),
-                cbCtx,
-            )  # type: ignore
-
-
-#
-# Obsolete, compatibility interfaces.
-#
-
-
-def __sendReqCbFun(
-    snmpEngine,
-    sendRequestHandle,
-    errorIndication,
-    errorStatus,
-    errorIndex,
-    varBinds,
-    cbCtx,
-):
-    cbFun, cbCtx = cbCtx
-    return cbFun(
-        sendRequestHandle, errorIndication, errorStatus, errorIndex, varBinds, cbCtx
-    )
-
-
-def _sendReq(
-    self,
-    snmpEngine,
-    targetName,
-    varBinds,
-    cbFun,
-    cbCtx=None,
-    contextEngineId=None,
-    contextName="",
-):
-    return self.sendVarBinds(
-        snmpEngine,
-        targetName,
-        contextEngineId,
-        contextName,
-        varBinds,
-        __sendReqCbFun,
-        (cbFun, cbCtx),
-    )
-
-
-def _sendBulkReq(
-    self,
-    snmpEngine,
-    targetName,
-    nonRepeaters,
-    maxRepetitions,
-    varBinds,
-    cbFun,
-    cbCtx=None,
-    contextEngineId=None,
-    contextName="",
-):
-    return self.sendVarBinds(
-        snmpEngine,
-        targetName,
-        contextEngineId,
-        contextName,
-        nonRepeaters,
-        maxRepetitions,
-        varBinds,
-        __sendReqCbFun,
-        (cbFun, cbCtx),
-    )
-
-
-# install compatibility wrappers
-GetCommandGenerator.sendReq = _sendReq  # type: ignore
-SetCommandGenerator.sendReq = _sendReq  # type: ignore
-NextCommandGenerator.sendReq = _sendReq  # type: ignore
-NextCommandGeneratorSingleRun.sendReq = _sendReq  # type: ignore
-BulkCommandGenerator.sendReq = _sendBulkReq  # type: ignore
-BulkCommandGeneratorSingleRun.sendReq = _sendBulkReq  # type: ignore
