@@ -5,31 +5,35 @@
 # License: https://www.pysnmp.com/pysnmp/license.html
 #
 import sys
-from pyasn1.compat.octets import null
-from pysnmp.entity.rfc3413 import config
-from pysnmp.proto.proxy import rfc2576
-from pysnmp.proto import rfc3411
-from pysnmp.proto.api import v2c
-from pysnmp.proto import errind, error
-from pysnmp.smi import view, rfc1902
-from pysnmp import nextid
-from pysnmp import debug
 
-getNextHandle = nextid.Integer(0x7FFFFFFF)
+
+from pysnmp import debug, nextid
+from pysnmp.entity.engine import SnmpEngine
+from pysnmp.entity.rfc3413 import config
+from pysnmp.proto import errind, error, rfc3411
+from pysnmp.proto.api import v2c
+from pysnmp.proto.proxy import rfc2576
+from pysnmp.smi.rfc1902 import ObjectType
+
+
+getNextHandle = nextid.Integer(0x7FFFFFFF)  # noqa: N816
 
 
 class NotificationOriginator:
-    acmID = 3  # default MIB access control method to use
+    """Notification originator."""
+
+    ACM_ID = 3  # default MIB access control method to use
 
     def __init__(self, **options):
+        """Create a Notification Originator application."""
         self.__pendingReqs = {}
         self.__pendingNotifications = {}
         self.snmpContext = options.pop("snmpContext", None)  # this is deprecated
         self.__options = options
 
-    def processResponsePdu(
+    def process_response_pdu(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         messageProcessingModel,
         securityModel,
         securityName,
@@ -42,6 +46,7 @@ class NotificationOriginator:
         sendPduHandle,
         cbInfo,
     ):
+        """Process SNMP PDU response."""
         sendRequestHandle, cbFun, cbCtx = cbInfo
 
         # 3.3.6d
@@ -64,10 +69,10 @@ class NotificationOriginator:
             origDiscoveryRetries,
         ) = self.__pendingReqs.pop(sendPduHandle)
 
-        snmpEngine.transportDispatcher.jobFinished(id(self))
+        snmpEngine.transport_dispatcher.job_finished(id(self))
 
         if statusInformation:
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponsePdu: sendRequestHandle {}, sendPduHandle {} statusInformation {}".format(
                     sendRequestHandle, sendPduHandle, statusInformation
                 )
@@ -86,7 +91,7 @@ class NotificationOriginator:
                 origRetries > origRetryCount
                 or origDiscoveryRetries > self.__options.get("discoveryRetries", 4)
             ):
-                debug.logger & debug.flagApp and debug.logger(
+                debug.logger & debug.FLAG_APP and debug.logger(
                     "processResponsePdu: sendRequestHandle %s, sendPduHandle %s retry count %d exceeded"
                     % (sendRequestHandle, sendPduHandle, origRetries)
                 )
@@ -97,12 +102,12 @@ class NotificationOriginator:
             timeoutInTicks = (
                 float(origTimeout)
                 / 100
-                / snmpEngine.transportDispatcher.getTimerResolution()
+                / snmpEngine.transport_dispatcher.get_timer_resolution()
             )
 
             # User-side API assumes SMIv2
             if messageProcessingModel == 0:
-                reqPDU = rfc2576.v2ToV1(origPdu)
+                reqPDU = rfc2576.v2_to_v1(origPdu)
                 pduVersion = 0
             else:
                 reqPDU = origPdu
@@ -110,7 +115,7 @@ class NotificationOriginator:
 
             # 3.3.6a
             try:
-                sendPduHandle = snmpEngine.msgAndPduDsp.sendPdu(
+                sendPduHandle = snmpEngine.message_dispatcher.send_pdu(
                     snmpEngine,
                     origTransportDomain,
                     origTransportAddress,
@@ -124,12 +129,12 @@ class NotificationOriginator:
                     reqPDU,
                     True,
                     timeoutInTicks,
-                    self.processResponsePdu,
+                    self.process_response_pdu,
                     (sendRequestHandle, cbFun, cbCtx),
                 )
             except error.StatusInformation:
                 statusInformation = sys.exc_info()[1]
-                debug.logger & debug.flagApp and debug.logger(
+                debug.logger & debug.FLAG_APP and debug.logger(
                     "processResponsePdu: sendRequestHandle {}: sendPdu() failed with {!r} ".format(
                         sendRequestHandle, statusInformation
                     )
@@ -143,9 +148,9 @@ class NotificationOriginator:
                 )
                 return
 
-            snmpEngine.transportDispatcher.jobStarted(id(self))
+            snmpEngine.transport_dispatcher.job_started(id(self))
 
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponsePdu: sendRequestHandle %s, sendPduHandle %s, timeout %d, retry %d of %d"
                 % (
                     sendRequestHandle,
@@ -177,13 +182,13 @@ class NotificationOriginator:
         # 3.3.6c
         # User-side API assumes SMIv2
         if messageProcessingModel == 0:
-            PDU = rfc2576.v1ToV2(PDU, origPdu)
+            PDU = rfc2576.v1_to_v2(PDU, origPdu)
 
         cbFun(snmpEngine, sendRequestHandle, None, PDU, cbCtx)
 
-    def sendPdu(
+    def send_pdu(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         targetName,
         contextEngineId,
         contextName,
@@ -191,42 +196,43 @@ class NotificationOriginator:
         cbFun=None,
         cbCtx=None,
     ):
+        """Send SNMP PDU to a target."""
         (
             transportDomain,
             transportAddress,
             timeout,
             retryCount,
             params,
-        ) = config.getTargetAddr(snmpEngine, targetName)
+        ) = config.get_target_address(snmpEngine, targetName)
 
         (
             messageProcessingModel,
             securityModel,
             securityName,
             securityLevel,
-        ) = config.getTargetParams(snmpEngine, params)
+        ) = config.get_target_parameters(snmpEngine, params)
 
         # User-side API assumes SMIv2
         if messageProcessingModel == 0:
-            reqPDU = rfc2576.v2ToV1(pdu)
+            reqPDU = rfc2576.v2_to_v1(pdu)
             pduVersion = 0
         else:
             reqPDU = pdu
             pduVersion = 1
 
         # 3.3.5
-        if reqPDU.tagSet in rfc3411.confirmedClassPDUs:
+        if reqPDU.tagSet in rfc3411.CONFIRMED_CLASS_PDUS:
             # Convert timeout in seconds into timeout in timer ticks
             timeoutInTicks = (
                 float(timeout)
                 / 100
-                / snmpEngine.transportDispatcher.getTimerResolution()
+                / snmpEngine.transport_dispatcher.get_timer_resolution()
             )
 
             sendRequestHandle = getNextHandle()
 
             # 3.3.6a
-            sendPduHandle = snmpEngine.msgAndPduDsp.sendPdu(
+            sendPduHandle = snmpEngine.message_dispatcher.send_pdu(
                 snmpEngine,
                 transportDomain,
                 transportAddress,
@@ -240,11 +246,11 @@ class NotificationOriginator:
                 reqPDU,
                 True,
                 timeoutInTicks,
-                self.processResponsePdu,
+                self.process_response_pdu,
                 (sendRequestHandle, cbFun, cbCtx),
             )
 
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "sendPdu: sendPduHandle %s, timeout %d" % (sendPduHandle, timeout)
             )
 
@@ -264,9 +270,9 @@ class NotificationOriginator:
                 0,
                 0,
             )
-            snmpEngine.transportDispatcher.jobStarted(id(self))
+            snmpEngine.transport_dispatcher.job_started(id(self))
         else:
-            snmpEngine.msgAndPduDsp.sendPdu(
+            snmpEngine.message_dispatcher.send_pdu(
                 snmpEngine,
                 transportDomain,
                 transportAddress,
@@ -283,18 +289,19 @@ class NotificationOriginator:
 
             sendRequestHandle = None
 
-            debug.logger & debug.flagApp and debug.logger("sendPdu: message sent")
+            debug.logger & debug.FLAG_APP and debug.logger("sendPdu: message sent")
 
         return sendRequestHandle
 
-    def processResponseVarBinds(
-        self, snmpEngine, sendRequestHandle, errorIndication, pdu, cbCtx
+    def process_response_varbinds(
+        self, snmpEngine: SnmpEngine, sendRequestHandle, errorIndication, pdu, cbCtx
     ):
+        """Process SNMP PDU response."""
         notificationHandle, cbFun, cbCtx = cbCtx
 
         self.__pendingNotifications[notificationHandle].remove(sendRequestHandle)
 
-        debug.logger & debug.flagApp and debug.logger(
+        debug.logger & debug.FLAG_APP and debug.logger(
             "processResponseVarBinds: notificationHandle {}, sendRequestHandle {}, errorIndication {}, pending requests {}".format(
                 notificationHandle,
                 sendRequestHandle,
@@ -304,7 +311,7 @@ class NotificationOriginator:
         )
 
         if not self.__pendingNotifications[notificationHandle]:
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "processResponseVarBinds: notificationHandle {}, sendRequestHandle {} -- completed".format(
                     notificationHandle, sendRequestHandle
                 )
@@ -314,9 +321,9 @@ class NotificationOriginator:
                 snmpEngine,
                 sendRequestHandle,
                 errorIndication,
-                pdu and v2c.apiPDU.getErrorStatus(pdu) or 0,
-                pdu and v2c.apiPDU.getErrorIndex(pdu, muteErrors=True) or 0,
-                pdu and v2c.apiPDU.getVarBinds(pdu) or (),
+                pdu and v2c.apiPDU.get_error_status(pdu) or 0,
+                pdu and v2c.apiPDU.get_error_index(pdu, muteErrors=True) or 0,
+                pdu and v2c.apiPDU.get_varbinds(pdu) or (),
                 cbCtx,
             )
 
@@ -324,17 +331,34 @@ class NotificationOriginator:
     # Higher-level API to Notification Originator. Supports multiple
     # targets, automatic var-binding formation and is fully LCD-driven.
     #
-    def sendVarBinds(
+    def send_varbinds(
         self,
-        snmpEngine,
+        snmpEngine: SnmpEngine,
         notificationTarget,
         contextEngineId,
         contextName,
-        varBinds=(),
+        varBinds: "tuple[ObjectType, ...]" = (),
         cbFun=None,
         cbCtx=None,
     ):
-        debug.logger & debug.flagApp and debug.logger(
+        """Send SNMP notification to a target.
+
+        Args:
+            snmpEngine (SnmpEngine): SNMP engine that is sending the notification.
+            notificationTarget (str): Target name as configured at the SNMP engine.
+            contextEngineId (str): SNMP engine ID of the context to send notification in.
+            contextName (str): SNMP context name to send notification in.
+            varBinds (tuple): SNMP variable bindings to send.
+            cbFun (callable): Callback function to call when response is received.
+            cbCtx (object): General-purpose data passed to the callback function.
+
+        Returns:
+            int: Notification handle that can be used to cancel the notification.
+
+        Raises:
+            PySnmpError: If SNMP notification PDU requires SNMPv2-MIB::snmpTrapOID.0 to be present.
+        """
+        debug.logger & debug.FLAG_APP and debug.logger(
             'sendVarBinds: notificationTarget {}, contextEngineId {}, contextName "{}", varBinds {}'.format(
                 notificationTarget,
                 contextEngineId or "<default>",
@@ -343,80 +367,89 @@ class NotificationOriginator:
             )
         )
 
+        mibBuilder = snmpEngine.get_mib_builder()
+
         if contextName:
-            (
-                __SnmpAdminString,
-            ) = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols(
+            (__SnmpAdminString,) = mibBuilder.import_symbols(
                 "SNMP-FRAMEWORK-MIB", "SnmpAdminString"
             )
             contextName = __SnmpAdminString(contextName)
 
         # 3.3
-        (notifyTag, notifyType) = config.getNotificationInfo(
+        notifyTag, notifyType = config.get_notification_info(
             snmpEngine, notificationTarget
         )
 
         notificationHandle = getNextHandle()
 
-        debug.logger & debug.flagApp and debug.logger(
-            "sendVarBinds: notificationHandle {}, notifyTag {}, notifyType {}".format(
-                notificationHandle, notifyTag, notifyType
-            )
+        debug.logger & debug.FLAG_APP and debug.logger(
+            "sendVarBinds: notificationHandle %s, notifyTag %s, "
+            "notifyType %s" % (notificationHandle, notifyTag, notifyType)
         )
 
-        varBinds = [(v2c.ObjectIdentifier(x), y) for x, y in varBinds]
+        inputVarBinds = [(v2c.ObjectIdentifier(x), y) for (x, y) in varBinds]
 
         # 3.3.2 & 3.3.3
-        (
-            snmpTrapOID,
-            sysUpTime,
-        ) = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols(
+        snmpTrapOID, sysUpTime = mibBuilder.import_symbols(
             "__SNMPv2-MIB", "snmpTrapOID", "sysUpTime"
         )
 
-        for idx in range(len(varBinds)):
-            if idx and varBinds[idx][0] == sysUpTime.getName():
-                if varBinds[0][0] == sysUpTime.getName():
-                    varBinds[0] = varBinds[idx]
+        snmpTrapOID = snmpTrapOID.getName()
+        sysUpTime, uptime = sysUpTime.getName(), sysUpTime.getSyntax()
+
+        # Add sysUpTime if not present already
+        if not inputVarBinds or inputVarBinds[0][0] != sysUpTime:
+            inputVarBinds.insert(0, (v2c.ObjectIdentifier(sysUpTime), uptime.clone()))
+
+        # Search for and reposition sysUpTime if it's elsewhere
+        for idx, varBind in enumerate(inputVarBinds[1:]):
+            if varBind[0] == sysUpTime:
+                inputVarBinds[0] = varBind
+                del inputVarBinds[idx + 1]
+                break
+
+        if len(inputVarBinds) < 2:
+            raise error.PySnmpError(
+                "SNMP notification PDU requires "
+                "SNMPv2-MIB::snmpTrapOID.0 to be present"
+            )
+
+        # Search for and reposition snmpTrapOID if it's elsewhere
+        for idx, varBind in enumerate(inputVarBinds[2:]):
+            if varBind[0] == snmpTrapOID:
+                del inputVarBinds[idx + 2]
+                if inputVarBinds[1][0] == snmpTrapOID:
+                    inputVarBinds[1] = varBind
                 else:
-                    varBinds.insert(0, varBinds[idx])
-                    del varBinds[idx]
+                    inputVarBinds.insert(1, varBind)
+                break
 
-            if varBinds[0][0] != sysUpTime.getName():
-                varBinds.insert(
-                    0,
-                    (
-                        v2c.ObjectIdentifier(sysUpTime.getName()),
-                        sysUpTime.getSyntax().clone(),
-                    ),
-                )
-
-        if len(varBinds) < 2 or varBinds[1][0] != snmpTrapOID.getName():
-            varBinds.insert(
-                1,
-                (v2c.ObjectIdentifier(snmpTrapOID.getName()), snmpTrapOID.getSyntax()),
+        if inputVarBinds[1][0] != snmpTrapOID:
+            raise error.PySnmpError(
+                "SNMP notification PDU requires "
+                "SNMPv2-MIB::snmpTrapOID.0 to be present"
             )
 
         sendRequestHandle = -1
 
-        debug.logger & debug.flagApp and debug.logger(
+        debug.logger & debug.FLAG_APP and debug.logger(
             f"sendVarBinds: final varBinds {varBinds}"
         )
 
-        for targetAddrName in config.getTargetNames(snmpEngine, notifyTag):
+        for targetAddrName in config.get_target_names(snmpEngine, notifyTag):
             (
                 transportDomain,
                 transportAddress,
                 timeout,
                 retryCount,
                 params,
-            ) = config.getTargetAddr(snmpEngine, targetAddrName)
+            ) = config.get_target_address(snmpEngine, targetAddrName)
             (
                 messageProcessingModel,
                 securityModel,
                 securityName,
                 securityLevel,
-            ) = config.getTargetParams(snmpEngine, params)
+            ) = config.get_target_parameters(snmpEngine, params)
 
             # 3.3.1 XXX
             # XXX filtering's yet to be implemented
@@ -425,7 +458,7 @@ class NotificationOriginator:
             #             (filterSubtree, filterMask,
             #              filterType) = config.getNotifyFilter(filterProfileName)
 
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "sendVarBinds: notificationHandle {}, notifyTag {} yields: transportDomain {}, transportAddress {!r}, securityModel {}, securityName {}, securityLevel {}".format(
                     notificationHandle,
                     notifyTag,
@@ -437,11 +470,11 @@ class NotificationOriginator:
                 )
             )
 
-            for varName, varVal in varBinds:
-                if varName in (sysUpTime.name, snmpTrapOID.name):
+            for varName, varVal in inputVarBinds:
+                if varName in (sysUpTime, snmpTrapOID):
                     continue
                 try:
-                    snmpEngine.accessControlModel[self.acmID].isAccessAllowed(
+                    snmpEngine.access_control_model[self.ACM_ID].is_access_allowed(
                         snmpEngine,
                         securityModel,
                         securityName,
@@ -451,12 +484,12 @@ class NotificationOriginator:
                         varName,
                     )
 
-                    debug.logger & debug.flagApp and debug.logger(
+                    debug.logger & debug.FLAG_APP and debug.logger(
                         f"sendVarBinds: ACL succeeded for OID {varName} securityName {securityName}"
                     )
 
                 except error.StatusInformation:
-                    debug.logger & debug.flagApp and debug.logger(
+                    debug.logger & debug.FLAG_APP and debug.logger(
                         "sendVarBinds: ACL denied access for OID {} securityName {}, droppping notification".format(
                             varName, securityName
                         )
@@ -471,24 +504,24 @@ class NotificationOriginator:
             else:
                 raise error.ProtocolError("Unknown notify-type %r", notifyType)
 
-            v2c.apiPDU.setDefaults(pdu)
-            v2c.apiPDU.setVarBinds(pdu, varBinds)
+            v2c.apiPDU.set_defaults(pdu)
+            v2c.apiPDU.set_varbinds(pdu, inputVarBinds)
 
             # 3.3.5
             try:
-                sendRequestHandle = self.sendPdu(
+                sendRequestHandle = self.send_pdu(
                     snmpEngine,
                     targetAddrName,
                     contextEngineId,
                     contextName,
                     pdu,
-                    self.processResponseVarBinds,
+                    self.process_response_varbinds,
                     (notificationHandle, cbFun, cbCtx),
                 )
 
             except error.StatusInformation:
                 statusInformation = sys.exc_info()[1]
-                debug.logger & debug.flagApp and debug.logger(
+                debug.logger & debug.FLAG_APP and debug.logger(
                     "sendVarBinds: sendRequestHandle {}: sendPdu() failed with {!r}".format(
                         sendRequestHandle, statusInformation
                     )
@@ -511,7 +544,7 @@ class NotificationOriginator:
                         )
                 return notificationHandle
 
-            debug.logger & debug.flagApp and debug.logger(
+            debug.logger & debug.FLAG_APP and debug.logger(
                 "sendVarBinds: notificationHandle %s, sendRequestHandle %s, timeout %d"
                 % (notificationHandle, sendRequestHandle, timeout)
             )
@@ -521,7 +554,7 @@ class NotificationOriginator:
                     self.__pendingNotifications[notificationHandle] = set()
                 self.__pendingNotifications[notificationHandle].add(sendRequestHandle)
 
-        debug.logger & debug.flagApp and debug.logger(
+        debug.logger & debug.FLAG_APP and debug.logger(
             "sendVarBinds: notificationHandle {}, sendRequestHandle {}, notification(s) sent".format(
                 notificationHandle, sendRequestHandle
             )
@@ -530,89 +563,5 @@ class NotificationOriginator:
         return notificationHandle
 
 
-#
-# Obsolete, compatibility interfaces.
-#
-
-
-def _sendNotificationCbFun(
-    snmpEngine,
-    sendRequestHandle,
-    errorIndication,
-    errorStatus,
-    errorIndex,
-    varBinds,
-    cbCtx,
-):
-    cbFun, cbCtx = cbCtx
-
-    try:
-        # we need to pass response PDU information to user for INFORMs
-        cbFun(
-            sendRequestHandle, errorIndication, errorStatus, errorIndex, varBinds, cbCtx
-        )
-    except TypeError:
-        # a backward compatible way of calling user function
-        cbFun(sendRequestHandle, errorIndication, cbCtx)
-
-
-def _sendNotification(
-    self,
-    snmpEngine,
-    notificationTarget,
-    notificationName,
-    additionalVarBinds=(),
-    cbFun=None,
-    cbCtx=None,
-    contextName=null,
-    instanceIndex=None,
-):
-    if self.snmpContext is None:
-        raise error.ProtocolError("SNMP context not specified")
-
-    #
-    # Here we first expand trap OID into associated OBJECTS
-    # and then look them up at context-specific MIB
-    #
-
-    mibViewController = snmpEngine.getUserContext("mibViewController")
-    if not mibViewController:
-        mibViewController = view.MibViewController(snmpEngine.getMibBuilder())
-        snmpEngine.setUserContext(mibViewController=mibViewController)
-
-    # Support the following syntax:
-    #   '1.2.3.4'
-    #   (1,2,3,4)
-    #   ('MIB', 'symbol')
-    if (
-        isinstance(notificationName, (tuple, list))
-        and notificationName
-        and isinstance(notificationName[0], str)
-    ):
-        notificationName = rfc1902.ObjectIdentity(*notificationName)
-    else:
-        notificationName = rfc1902.ObjectIdentity(notificationName)
-
-    varBinds = rfc1902.NotificationType(notificationName, instanceIndex=instanceIndex)
-    varBinds.resolveWithMib(mibViewController)
-
-    mibInstrumController = self.snmpContext.getMibInstrum(contextName)
-
-    varBinds = varBinds[:1] + mibInstrumController.readVars(varBinds[1:])
-
-    return self.sendVarBinds(
-        snmpEngine,
-        notificationTarget,
-        self.snmpContext.contextEngineId,
-        contextName,
-        varBinds + list(additionalVarBinds),
-        _sendNotificationCbFun,
-        (cbFun, cbCtx),
-    )
-
-
-# install compatibility wrapper
-NotificationOriginator.sendNotification = _sendNotification
-
 # XXX
 # move/group/implement config setting/retrieval at a stand-alone module
